Class: Google::Cloud::Language::V1beta2::ClassificationModelOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Language::V1beta2::ClassificationModelOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/language/v1beta2/language_service.rb
Overview
Model options available for classification requests.
Defined Under Namespace
Instance Attribute Summary collapse
-
#v1_model ⇒ ::Google::Cloud::Language::V1beta2::ClassificationModelOptions::V1Model
Setting this field will use the V1 model and V1 content categories version.
-
#v2_model ⇒ ::Google::Cloud::Language::V1beta2::ClassificationModelOptions::V2Model
Setting this field will use the V2 model with the appropriate content categories version.
Instance Attribute Details
#v1_model ⇒ ::Google::Cloud::Language::V1beta2::ClassificationModelOptions::V1Model
Returns Setting this field will use the V1 model and V1 content categories version. The V1 model is a legacy model; support for this will be discontinued in the future.
Note: The following fields are mutually exclusive: v1_model, v2_model. If a field in that set is populated, all other fields in the set will automatically be cleared.
940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'proto_docs/google/cloud/language/v1beta2/language_service.rb', line 940 class ClassificationModelOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for the V1 model. class V1Model include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for the V2 model. # @!attribute [rw] content_categories_version # @return [::Google::Cloud::Language::V1beta2::ClassificationModelOptions::V2Model::ContentCategoriesVersion] # The content categories used for classification. class V2Model include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The content categories used for classification. module ContentCategoriesVersion # If `ContentCategoriesVersion` is not specified, this option will # default to `V1`. CONTENT_CATEGORIES_VERSION_UNSPECIFIED = 0 # Legacy content categories of our initial launch in 2017. V1 = 1 # Updated content categories in 2022. V2 = 2 end end end |
#v2_model ⇒ ::Google::Cloud::Language::V1beta2::ClassificationModelOptions::V2Model
Returns Setting this field will use the V2 model with the appropriate content categories version. The V2 model is a better performing model.
Note: The following fields are mutually exclusive: v2_model, v1_model. If a field in that set is populated, all other fields in the set will automatically be cleared.
940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'proto_docs/google/cloud/language/v1beta2/language_service.rb', line 940 class ClassificationModelOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Options for the V1 model. class V1Model include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Options for the V2 model. # @!attribute [rw] content_categories_version # @return [::Google::Cloud::Language::V1beta2::ClassificationModelOptions::V2Model::ContentCategoriesVersion] # The content categories used for classification. class V2Model include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The content categories used for classification. module ContentCategoriesVersion # If `ContentCategoriesVersion` is not specified, this option will # default to `V1`. CONTENT_CATEGORIES_VERSION_UNSPECIFIED = 0 # Legacy content categories of our initial launch in 2017. V1 = 1 # Updated content categories in 2022. V2 = 2 end end end |